{ FORCE, WEIGHT, GRAVITATIONAL FORCE? }: https://www.nist.gov/pml/owm/approximate-conversions-us-customary-measures-metric US CUSTOMARY UNITS: POUND: POUND OF FORCE: { STANDARD ACCELERATION DUE TO GRAVITY } = (32.174049 FEET) / (SECONDS ^ 2) 1 lbf = (1 POUND * 32.174049 FEET) / (SECONDS ^ 2) CONVERSION: 1 POUND OF FORCE = 4.448222 NEWTONS (1 POUND * 32.174049 FEET) / (SECONDS ^ 2) = (.45 KILOGRAMS * 9.80665 METERS) / (SECONDS ^ 2) POUNDAL: POUNDAL = (1 POUND * 1 FOOT) / (SECONDS ^ 2) SLUG: SYSTEM INTERNATIONAL: 1 NEWTON: 1 NEWTON = (1 KILOGRAM * METERS) / (SECONDS ^ 2) EXAMPLES: (50 kg) * (9.90665 METERS / SECONDS ** 2) ~= 495.3325 NEWTONS